// RemoteRoster.h
// 
// Copyright (c) 2004, Ingo Weinhold (bonefish@cs.tu-berlin.de)
// 
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of a copyright holder shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization of the
// copyright holder.

#ifndef REMOTE_ROSTER_H
#define REMOTE_ROSTER_H

#include <RMessageBuild.h>

#include <Archivable.h>
#include <Messenger.h>
#include <NetAddress.h>
#include <OS.h>

struct app_info;
class BList;
class RemoteRosterImpl;

class _IMPEXP_RMESSAGE RemoteRoster {
public:
								RemoteRoster(const BNetAddress* address = NULL);
								RemoteRoster(const char* host);
								~RemoteRoster();

			status_t			SetTo(const BNetAddress* address);
			status_t			SetTo(const char* host);
			void				Unset();
			status_t			InitCheck() const;

			status_t			GetAppList(BList* teams) const;
			status_t			GetAppList(const char* signature,
									BList* teams) const;
			team_id				TeamFor(const char* signature) const;
			status_t			GetRunningAppInfo(const char* signature,
									app_info* info) const;
			status_t			GetRunningAppInfo(team_id team,
									app_info* info) const;
			status_t			GetActiveAppInfo(app_info* info) const;

			status_t			GetMessenger(const char* signature,
									BMessenger* messenger,
									bool byName = false) const;
			status_t			GetMessenger(team_id team,
									BMessenger* messenger) const;

private:
			status_t			fInitStatus;
			BNetAddress*		fAddress;
			RemoteRosterImpl*	fImpl;
};

#endif	// REMOTE_ROSTER_H
